[tarantool-patches] Re: [PATCH] jdbc: fix primary keys meta retrieval

Alexander Turenko alexander.turenko at tarantool.org
Wed Oct 10 15:50:20 MSK 2018


On Wed, Oct 10, 2018 at 02:09:48PM +0300, Sergei Kalashnikov wrote:
> Sure. Please find the amended patch at the very end of this mail.
> 

Found one more such case. Sorry, missed that before.

diff --git a/src/test/java/org/tarantool/jdbc/JdbcExceptionHandlingTest.java b/src/test/java/org/tarantool/jdbc/JdbcExceptionHandlingTest.java
index 39d6326..8cc7acc 100644
--- a/src/test/java/org/tarantool/jdbc/JdbcExceptionHandlingTest.java
+++ b/src/test/java/org/tarantool/jdbc/JdbcExceptionHandlingTest.java
@@ -25,10 +25,10 @@ public class JdbcExceptionHandlingTest {
     /**
      * Simulates meta parsing error: missing "name" field in a space format for the primary key.
      *
      * @throws Exception on failure.
      */
     @Test
-    public void testDatabaseMetaDataGetPrimaryKeysFormatError() throws Exception {
+    public void testDatabaseMetaDataGetPrimaryKeysFormatError() throws SQLException {
         TarantoolConnection tntCon = mock(TarantoolConnection.class);
         SQLConnection conn = new SQLConnection(tntCon, "", new Properties());
@@ -25,10 +25,10 @@ public class JdbcExceptionHandlingTest {
      * Simulates meta parsing error: missing "name" field in a space format for the primary key.
      *
-     * @throws Exception on failure.
+     * @throws SQLException on failure.
      */
     @Test

You can don't attach the whole patch in case of such small code tweaks
(at least for me), because we anyway kept in sync using the repository.

WBR, Alexander Turenko.




More information about the Tarantool-patches mailing list